==> flutter_catalogue_widgets-0.0.16.tar.gz: lib/custom-image.dart <==
/*
Description:
A widget that displays images. It can display both network and asset images depending on the input of the user.

Usage:
The user can pass the img source(accepts both local source as well as link to an image from internet), the type of image,
height and width of the image and quality of the image.
The user also passes a callback function to return the semanticLabel of the image which is invoked when the widget is used.

onclick(String sText) {
      print(sText);
    }

  CustomImageContents ImageObj1 = new CustomImageContents(src:"http://miro.medium.com/max/3840/1*88vrIIpPfApKYwQeWw32xg.png", semanticLabel: "Random Network", imageType: 'Network', height: 200, width: 200);
  CustomImageContents ImageObj2 = new CustomImageContents(src:"images/rest1.jpeg", semanticLabel: "Asset Restaurant", imageType: 'Asset', height: 200, width: 800, filterQuality: FilterQuality.high );

  CustomImage(data: ImageObj1)
  CustomImage(data: ImageObj2)

  imports:
  import 'package:flutter/material.dart';
  import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
  import 'package:flutter_widgets_library/utils/package:flutter_catalogue_widgets/consts.dart' as cons;
  import 'custom-image.dart';


Author:
Anubhav Sinha
*/

import 'package:flutter/material.dart';
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';
import 'package:flutter_catalogue_widgets/consts.dart' as cons;

class CustomImage extends StatefulWidget {
  final CustomImageContents data;
  final Function(String)callbackImage;

  const CustomImage({
    Key key, @required this.data, this.callbackImage
  })  :
        super(key: key);

  @override
  _CustomImageState createState() {
    
    return _CustomImageState(this.data, this.callbackImage);
  }
}

class _CustomImageState extends State<CustomImage> {
  CustomImageContents data;
  Function callbackImage;
  _CustomImageState(CustomImageContents data, Function callbackImage){
    this.data = data;
    this.callbackImage = callbackImage;
  }
  @override
  // ignore: missing_return
  Widget build(BuildContext context) {
    if (data.imageType == 'network' || data.imageType == 'Network') {
      return GestureDetector(
          onTap: () { callbackImage(data.semanticLabel); },
          child: new Container(
          child: Image(
            image: NetworkImage(data.src),
            fit: BoxFit.cover,
            colorBlendMode: data.colorBlendMode,
            filterQuality: (data.filterQuality != null)? data.filterQuality: FilterQuality.high,
            semanticLabel: data.semanticLabel,
            height: (data.height != null)? data.height:cons.heightFourHundred,
            width: (data.width != null)? data.width:cons.heightFourHundred,
          ),
        ),
      );
    } else if (data.imageType == 'asset' || data.imageType == 'Asset') {
      return GestureDetector(
        onTap: () { callbackImage(data.semanticLabel); },
          child: new Container(
          child: Image(
            image: AssetImage(data.src),
            fit: BoxFit.cover,
            colorBlendMode: data.colorBlendMode,
            filterQuality: (data.filterQuality != null)? data.filterQuality: FilterQuality.high,
            semanticLabel: data.semanticLabel,
            height: (data.height != null)? data.height:cons.heightFourHundred,
            width: (data.width != null)? data.width:cons.heightFourHundred,
          ),
        ),
      );
    }
  }
}

==> flutter_catalogue_widgets-0.0.25.tar.gz: lib/custom-image.dart <==
/*
Description:
A widget that displays images. It can display both network and asset images depending on the input of the user.

Usage:
The user can pass the img source(accepts both local source as well as link to an image from internet), the type of image,
height and width of the image and quality of the image.
The user also passes a callback function to return the semanticLabel of the image which is invoked when the widget is used.

onclick(String sText) {
      print(sText);
    }

  CustomImageContents ImageObj1 = new CustomImageContents(src:"http://miro.medium.com/max/3840/1*88vrIIpPfApKYwQeWw32xg.png", semanticLabel: "Random Network", imageType: 'Network', height: 200, width: 200);
  CustomImageContents ImageObj2 = new CustomImageContents(src:"images/rest1.jpeg", semanticLabel: "Asset Restaurant", imageType: 'Asset', height: 200, width: 800, filterQuality: FilterQuality.high );

  CustomImage(data: ImageObj1)
  CustomImage(data: ImageObj2)

  imports:
  import 'package:flutter/material.dart';
  import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
  import 'package:flutter_widgets_library/utils/package:flutter_catalogue_widgets/consts.dart' as cons;
  import 'custom-image.dart';


Author:
Anubhav Sinha
*/

import 'package:flutter/material.dart';
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';
import 'package:flutter_catalogue_widgets/consts.dart' as cons;

class CustomImage extends StatefulWidget {
  final CustomImageContents data;
  final Function(String) callbackImage;

  const CustomImage({Key key, @required this.data, this.callbackImage})
      : super(key: key);

  @override
  _CustomImageState createState() {
    return _CustomImageState(this.data, this.callbackImage);
  }
}

class _CustomImageState extends State<CustomImage> {
  CustomImageContents data;
  Function callbackImage;
  _CustomImageState(CustomImageContents data, Function callbackImage) {
    this.data = data;
    this.callbackImage = callbackImage;
  }
  @override
  // ignore: missing_return
  Widget build(BuildContext context) {
    if (data.imageType == 'network' || data.imageType == 'Network') {
      return GestureDetector(
        onTap: () {
          callbackImage(data.semanticLabel);
        },
        child: new Container(
          child: Image(
            image: NetworkImage(data.src),
            fit: BoxFit.cover,
            colorBlendMode: data.colorBlendMode,
            filterQuality: (data.filterQuality != null)
                ? data.filterQuality
                : FilterQuality.high,
            semanticLabel: data.semanticLabel,
            height:
                (data.height != null) ? data.height : cons.heightFourHundred,
            width: (data.width != null) ? data.width : cons.heightFourHundred,
          ),
        ),
      );
    } else if (data.imageType == 'asset' || data.imageType == 'Asset') {
      return GestureDetector(
        onTap: () {
          callbackImage(data.semanticLabel);
        },
        child: new Container(
          child: Image(
            image: AssetImage(data.src),
            fit: BoxFit.cover,
            colorBlendMode: data.colorBlendMode,
            filterQuality: (data.filterQuality != null)
                ? data.filterQuality
                : FilterQuality.high,
            semanticLabel: data.semanticLabel,
            height:
                (data.height != null) ? data.height : cons.heightFourHundred,
            width: (data.width != null) ? data.width : cons.heightFourHundred,
          ),
        ),
      );
    }
  }
}
